Learn R Programming

mixlm (version 1.0.8.1)

anova.lm: Analysis of variance (sequential SS)

Description

Wrapper for anova.lm in package stats that halts execution if unsupported input is detected.

Usage

## S3 method for class 'lm':
anova(object, ...)

Arguments

object
object fitted by lm, lmer or similar.
...
possible additional argument to underlying functions.

Value

  • Returns appropriate analysis of variance or halts if unsupported input is detected.

encoding

latin1

See Also

lm

Examples

Run this code
mixlm <- lm(y~x*r(z),
			data = data.frame(y = rnorm(8),
							  x = factor(c(rep(1,4),rep(0,4))),
							  z = factor(rep(c(1,0),4))))
anova(mixlm)

Run the code above in your browser using DataLab