Learn R Programming

mixlm (version 1.0.8.1)

print.summary.lm: Summarizing Linear Model Fits

Description

summary method for class "lm".

Usage

## S3 method for class 'summary.lm':
print(x, digits = max(3, getOption("digits") - 3),
      symbolic.cor = x$symbolic.cor,
      signif.stars = getOption("show.signif.stars"), ...)

Arguments

x
an object of class "summary.lm", usually, a result of a call to summary.lm.
digits
the number of significant digits to use when printing.
symbolic.cor
logical. If TRUE, print the correlations in a symbolic form (see symnum) rather than as numbers.
signif.stars
logical. If TRUE, significance stars are printed for each coefficient.
...
further arguments passed to or from other methods.

Value

  • The function summary.lm computes and returns a list of summary statistics of the fitted linear model given in object, using the components (list elements) "call" and "terms" from its argument, plus
  • residualsthe weighted residuals, the usual residuals rescaled by the square root of the weights specified in the call to lm.
  • coefficientsa $p \times 4$ matrix with columns for the estimated coefficient, its standard error, t-statistic and corresponding (two-sided) p-value. Aliased coefficients are omitted.
  • aliasednamed logical vector showing if the original coefficients are aliased.
  • sigmathe square root of the estimated variance of the random error $$\hat\sigma^2 = \frac{1}{n-p}\sum_i{w_i R_i^2},$$ where $R_i$ is the $i$-th residual, residuals[i].
  • dfdegrees of freedom, a 3-vector $(p, n-p, p*)$, the last being the number of non-aliased coefficients.
  • fstatistic(for models including non-intercept terms) a 3-vector with the value of the F-statistic with its numerator and denominator degrees of freedom.
  • r.squared$R^2$, the fraction of variance explained by the model, $$R^2 = 1 - \frac{\sum_i{R_i^2}}{\sum_i(y_i- y^*)^2},$$ where $y^*$ is the mean of $y_i$ if there is an intercept and zero otherwise.
  • adj.r.squaredthe above $R^2$ statistic adjusted, penalizing for higher $p$.
  • cov.unscaleda $p \times p$ matrix of (unscaled) covariances of the $\hat\beta_j$, $j=1, \dots, p$.
  • correlationthe correlation matrix corresponding to the above cov.unscaled, if correlation = TRUE is specified.
  • symbolic.cor(only if correlation is true.) The value of the argument symbolic.cor.
  • na.actionfrom object, if present there.

Details

This adaptation of print.summary.lm from package stats slightly alters the output to better conform with text-book notation. print.summary.lm tries to be smart about formatting the coefficients, standard errors, etc. and additionally gives significance stars if signif.stars is TRUE. Correlations are printed to two decimal places (or symbolically): to see the actual correlations print summary(object)$correlation directly.

See Also

The model fitting function lm, summary. Function coef will extract the matrix of coefficients with standard errors, t-statistics and p-values.

Examples

Run this code
ctl <- c(4.17,5.58,5.18,6.11,4.50,4.61,5.17,4.53,5.33,5.14)
trt <- c(4.81,4.17,4.41,3.59,5.87,3.83,6.03,4.89,4.32,4.69)
group <- gl(2,10,20, labels=c("Ctl","Trt"))
weight <- c(ctl, trt)
sld90 <- summary(lm.D90 <- lm(weight ~ group -1))# omitting intercept
sld90

Run the code above in your browser using DataLab