summary method for class "lmm".## S3 method for class 'summary.lmm':
print(x, digits = max(3, getOption("digits") - 3),
symbolic.cor = x$symbolic.cor,
signif.stars = getOption("show.signif.stars"), ...)"summary.lmm", usually, a result of a
call to summary.lmm.TRUE, print the correlations in
a symbolic form (see symnum) rather than as numbers.TRUE, summary.lm computes and returns a list of summary
statistics of the fitted linear model given in object, using
the components (list elements) "call" and "terms"
from its argument, pluslm.residuals[i].cov.unscaled, if correlation = TRUE is specified.correlation is true.) The value
of the argument symbolic.cor.object, if present there.print.summary.lm from package stats
slightly alters the output to better conform with text-book notation.
print.summary.lm tries to be smart about formatting the
coefficients, standard errors, etc. and additionally gives
signif.stars is TRUE.
Correlations are printed to two decimal places (or symbolically): to
see the actual correlations print summary(object)$correlation
directly.lm, summary.
Function coef will extract the matrix of coefficients
with standard errors, t-statistics and p-values.ctl <- c(4.17,5.58,5.18,6.11,4.50,4.61,5.17,4.53,5.33,5.14)
trt <- c(4.81,4.17,4.41,3.59,5.87,3.83,6.03,4.89,4.32,4.69)
group <- gl(2,10,20, labels=c("Ctl","Trt"))
weight <- c(ctl, trt)
sld90 <- summary(lm.D90 <- lm(weight ~ group -1))# omitting intercept
sld90Run the code above in your browser using DataLab