simple.glht(mod, effect, corr = c("Tukey","Bonferroni","Fisher"),
level = 0.95, ...)Tukey."simple.glht", "summary.glht"
and "glht" containing information to produce confidence intervals,
tests and plotting.
There are print, plot and cld methods for class
"simple.glht".
The plot method does not accept
xlab, ylab or main arguments and creates its own
values for each plot.which specifies non-factor terms these will be dropped with
a warning: if no terms are left this is a an error.aov, qtukey, model.tables,
glht in package require(graphics)
summary(fm1 <- lm(breaks ~ wool + tension, data = warpbreaks))
simple.glht(fm1, "tension")
plot(simple.glht(fm1, "tension"))
cld(simple.glht(fm1, "tension"))Run the code above in your browser using DataLab